@@ -14,6 +14,9 @@ except:
     concurrent_count = 1
 celery.conf.setdefault('CELERYD_CONCURRENCY', concurrent_count)  # 设置任务并发数,默认是1
 
+# 这里增加一个这个配置,改成12小时,默认情况下redis做后端会有一个1小时的默认超时时间,也就是放到unacked的任务,一个小时就会被重新放入到task队列中. @see https://docs.celeryproject.org/en/stable/getting-started/backends-and-brokers/redis.html#redis-caveats
+celery.conf.broker_transport_options = {'visibility_timeout': 43200}
+
 redis_url: str = annotation.get_value("${redis.url:}")
 
 if redis_url is None or redis_url.strip() == '':
@@ -35,7 +38,7 @@ if redis_url is None or redis_url.strip() == '':
                 f'sentinel://{f":{password}@" if (password is not None and password != "") else ""}{url}/{database}'
                 for
                 url in split])
-        celery.conf.broker_transport_options = {'master_name': master}
+        celery.conf.broker_transport_options['master_name'] = master
         celery.conf.result_backend_transport_options = {'master_name': master}
 else:
     try:
@@ -66,7 +69,7 @@ else:
                 f'sentinel://{f":{redis_password}@" if (redis_password is not None and redis_password != "") else ""}{url}/{redis_database}'
                 for
                 url in split])
-        celery.conf.broker_transport_options = {'master_name': sentinel}
+        celery.conf.broker_transport_options['master_name'] = sentinel
         celery.conf.result_backend_transport_options = {'master_name': sentinel}
     else:
         # 说明是单机
