@@ -15,6 +15,9 @@ from __future__ import absolute_import
 # 不提前缓存4个任务,收一个任务,做一个任务
 CELERYD_PREFETCH_MULTIPLIER = 1
 
+# 延迟进行ACK的确认,只有当任务结束(成功/失败)后,再进行ACK的确认.这样做的目的是避免执行器进行 PREFETCH.在我们的场景里面预取问题很大
+CELERY_ACKS_LATE = True
+
 # CELERYD_CONCURRENCY = 1     # 并发任务数
 
 # 记录任务的开始状态 否则就只有PENDING状态.   并且这个状态只任务结束24小时内有效.
