@@ -3,6 +3,7 @@
 # Author: lvbiao
 # Created on 2019/1/22
 from enum import Enum
+from urllib.parse import unquote
 
 from redis import StrictRedis
 
@@ -184,7 +185,7 @@ class RedisDatasource(BaseDatasource):
                 else:
                     url_tmp['host'] = url_split
                 if password:
-                    url_tmp['password'] = password
+                    url_tmp['password'] = unquote(password)
 
                 result.append(url_tmp)
             return (type, result,)
@@ -207,6 +208,6 @@ class RedisDatasource(BaseDatasource):
             # 普通单节点
             type = RedisTypeEnum.SINGLE
             # 构造url:  redis://[:password]@localhost:6379/0
-            password = ':' + str(password) + '@' if password else ''
+            password = ':' + unquote(str(password)) + '@' if password else ''
             url = f'redis://{password}{self.url}'
             return (type, url)
