@@ -953,25 +953,47 @@ class DiscoveryClient:
     def walk_nodes(self, app_name="", service="", prefer_ip=False, prefer_https=False, walker=None):
         assert app_name is not None and app_name != "", "application_name should not be null"
         assert inspect.isfunction(walker) or inspect.ismethod(walker), "walker must be a method or function"
-        error_nodes = []
-        app_name = app_name.upper()
-        node = self.__get_available_service(app_name)
 
-        while node is not None:
-            try:
-                url = self.__generate_service_url(node, prefer_ip, prefer_https)
-                if service.startswith("/"):
-                    url = url + service[1:]
-                else:
-                    url = url + service
-                _logger.debug("service url::" + url)
-                return walker(url)
-            except (http_client.HTTPError, http_client.URLError):
-                _logger.warn("do service %s in node [%s] error, use next node." % (service, node.instanceId))
-                error_nodes.append(node.instanceId)
-                node = self.__get_available_service(app_name, error_nodes)
+        from config import work_on_k8s, k8s_ficus_server_service, k8s_config_server_service, k8s_schedule_server_service
+        if work_on_k8s:
+            # 如果运行在k8s服务上,那么就可以不走注册中心
+            # 这里简单的实现
+            url = k8s_ficus_server_service
+            if app_name.lower() == "sobeycloud-schedule-service":
+                url = k8s_schedule_server_service
+            elif app_name.lower() == "sobeyficus-config-server":
+                url = k8s_config_server_service
+            else:
+                url = k8s_ficus_server_service
+            if not url.endswith("/"):
+                url = url + "/"
+            if service.startswith("/"):
+                url = url + service[1:]
+            else:
+                url = url + service
+            _logger.debug("service url::" + url)
+            return walker(url)
+        else:
+            # 如果没运行在k8s服务上
+            error_nodes = []
+            app_name = app_name.upper()
+            node = self.__get_available_service(app_name)
 
-        raise http_client.URLError("Try all up instances in registry, but all fail")
+            while node is not None:
+                try:
+                    url = self.__generate_service_url(node, prefer_ip, prefer_https)
+                    if service.startswith("/"):
+                        url = url + service[1:]
+                    else:
+                        url = url + service
+                    _logger.debug("service url::" + url)
+                    return walker(url)
+                except (http_client.HTTPError, http_client.URLError):
+                    _logger.warn("do service %s in node [%s] error, use next node." % (service, node.instanceId))
+                    error_nodes.append(node.instanceId)
+                    node = self.__get_available_service(app_name, error_nodes)
+
+            raise http_client.URLError("Try all up instances in registry, but all fail")
 
     def do_service_async(self, app_name="", service="", return_type="string",
                          prefer_ip=False, prefer_https=False,
