@@ -6,7 +6,7 @@ import os
 import yaml
 
 REGISTRY_PROPERTIES = dict()
-
+ALGORITHM_PROPERTIES = dict()
 
 def load_registry_properties(file, yaml_name: str):
     yaml = read_yaml_file(file, yaml_name)
@@ -15,6 +15,12 @@ def load_registry_properties(file, yaml_name: str):
     global REGISTRY_PROPERTIES
     REGISTRY_PROPERTIES = yaml["sobeyficus"]["registry"]
 
+def load_algorithm_properties(file, yaml_name: str):
+    yaml = read_yaml_file(file, yaml_name)
+    if yaml is None:
+        return
+    global ALGORITHM_PROPERTIES
+    ALGORITHM_PROPERTIES = yaml["algorithm"]
 
 def read_yaml_file(file, yaml_name: str, profile: str = 'default'):
     """
